from random import choice
from supportive_functions import generate_surname_less


female_names = [
    "Adelaide",
    "Adriana",
    "Amara",
    "Amaryllis",
    "Anastasia",
    "Arabella",
    "Ariadne",
    "Arianwen",
    "Astoria",
    "Aurelia",
    "Brielle",
    "Calliope",
    "Cassandra",
    "Celestia",
    "Cressida",
    "Dahlia",
    "Elara",
    "Eleanor",
    "Elowen",
    "Elysia",
    "Emmeline",
    "Evaine",
    "Evangeline",
    "Evelina",
    "Fiona",
    "Fiora",
    "Genevieve",
    "Ginevra",
    "Giselle",
    "Guinevere",
    "Gwendolyn",
    "Helena",
    "Helene",
    "Iliana",
    "Imelda",
    "Isabeau",
    "Isolde",
    "Jessamine",
    "Jocelyn",
    "Lavinia",
    "Lorelei",
    "Lyra",
    "Maelisande",
    "Marigold",
    "Melisande",
    "Mirella",
    "Morgana",
    "Morwenna",
    "Nerissa",
    "Octavia",
    "Ophelia",
    "Oriana",
    "Pandora",
    "Persephone",
    "Quintessa",
    "Ravenna",
    "Rosalind",
    "Rosamund",
    "Rowena",
    "Sabrina",
    "Selene",
    "Seraphina",
    "Seraphine",
    "Sylvana",
    "Tatiana",
    "Thalia",
    "Titania",
    "Ursula",
    "Vespera",
    "Viola",
    "Vivienne",
    "Wilhelmina",
    "Winifred",
    "Xanthe",
    "Yara",
    "Yvette",
    "Zephyrine",
]

male_names = [
    "Arthur",
    "Lancelot",
    "Gawain",
    "Tristan",
    "Gareth",
    "Percival",
    "Galahad",
    "Lysander",
    "Valerian",
    "Benedict",
    "Cedric",
    "Edric",
    "Finnian",
    "Hector",
    "Leander",
    "Theobald",
    "Ambrose",
    "Dorian",
    "Edmund",
    "Frederick",
    "Gerard",
    "Harold",
    "Jareth",
    "Luther",
    "Merrick",
    "Oswald",
    "Reginald",
    "Sylvester",
    "Tristram",
    "Ulric",
    "Wilfred",
    "Caius",
    "Emeric",
    "Gideon",
    "Hadrian",
    "Jasper",
    "Leopold",
    "Maximilian",
    "Oberon",
    "Quentin",
    "Roderick",
    "Sebastian",
    "Thaddeus",
    "Ulysses",
    "Victor",
    "Xander",
    "Yorick",
    "Zephyr",
    "Balthazar",
    "Cassius",
    "Dominic",
    "Ezekiel",
    "Felix",
    "Gareth",
    "Horatio",
    "Ignatius",
    "Jeremiah",
    "Kieran",
    "Lazarus",
    "Magnus",
    "Nathaniel",
    "Orlando",
    "Peregrine",
    "Quirinus",
    "Raphael",
    "Solomon",
    "Theron",
    "Uriah",
    "Vance",
    "Winston",
    "Xavier",
    "Yale",
    "Zacharias",
]

surname_prefix = [
    "amber",
    "black",
    "blade",
    "blaze",
    "blood",
    "bright",
    "dark",
    "dawn",
    "dragon",
    "dusk",
    "fire",
    "frost",
    "golden",
    "hawk",
    "iron",
    "mist",
    "moon",
    "night",
    "oak",
    "raven",
    "shadow",
    "silver",
    "star",
    "steel",
    "stone",
    "storm",
    "swift",
    "sword",
    "thorn",
    "thunder",
    "valiant",
    "white",
    "wind",
    "winter",
    "wolf"
]

surname_suffix = [
    "shard",
    "scale",
    "sword",
    "thistle",
    "thorn",
    "walker",
    "wind",
    "fire",
    "moon",
    "raven",
    "rider",
    "blade",
    "flame",
    "wing",
    "wood",
    "bane",
    "storm",
    "shadow",
    "dusk",
    "fall",
    "hawk",
    "bark",
    "fang",
    "fist",
    "foot",
    "helm",
    "mist",
    "stone",
    "beard",
    "weaver",
    "shadow",
    "shield",
    "spear",
    "leaf",
    "mantle",
    "eye",
    "claw",
    "caster",
    "vale",
    "blood",
    "brook",
    "song",
    "thorn",
    "wing",
    "fire",
    "shield",
    "heart",
    "thistle",
    "thorn",
    "shadow",
    "wood",
    "bane",
    "blade",
    "caster",
    "claw",
    "fall",
    "fire",
    "heart",
    "storm",
    "thorn",
    "vale",
    "brook",
    "shield",
    "spear",
    "stone",
    "thistle",
    "thorn",
    "wing",
    "fire",
    "shield",
    "heart",
    "song",
    "spear",
    "sword",
    "warden",
    "watch",
    "arrow",
    "brook",
    "foot",
    "steel",
    "strike",
    "wind",
    "breaker",
    "field",
    "heart",
    "thunder",
    "strike",
    "heart",
    "thorn",
    "storm",
    "bane"
]

female = choice(female_names)
male = choice(male_names)
surname = generate_surname_less(surname_prefix, surname_suffix)
